pub struct Gutter { /* private fields */ }Expand description
The gutter: components in draw order.
Implementations
Sourceimpl Gutter
impl Gutter
pub fn new(components: Vec<GutterComponent>) -> Self
Sourcepub fn width(&self, line_count: usize) -> usize
pub fn width(&self, line_count: usize) -> usize
Total cells, summed across components. Zero for an empty gutter, which is how the column is turned off without a second code path.
Sourcepub fn render_line(
&self,
line: usize,
cursor_line: usize,
line_count: usize,
theme: &ThemeColors,
) -> Vec<Span<'static>>
pub fn render_line( &self, line: usize, cursor_line: usize, line_count: usize, theme: &ThemeColors, ) -> Vec<Span<'static>>
The spans for one buffer line.